@@ -1,8 +1,10 @@
-/* Copyright 2012--2017 The Tor Project
+/* Copyright 2012--2020 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.descriptor;
 
+import java.io.Serializable;
+
 /**
  * Contains the signature of a network status consensus or vote.
  *
@@ -13,7 +15,7 @@ package org.torproject.descriptor;
  *
  * @since 1.0.0
  */
-public interface DirectorySignature {
+public interface DirectorySignature extends Serializable {
 
   /**
    * Return the digest algorithm, which is "sha1" by default and which
@@ -21,7 +23,7 @@ public interface DirectorySignature {
    *
    * @since 1.0.0
    */
-  public String getAlgorithm();
+  String getAlgorithm();
 
   /**
    * Return the SHA-1 digest of the authority's long-term identity key in
@@ -30,7 +32,7 @@ public interface DirectorySignature {
    *
    * @since 1.0.0
    */
-  public String getIdentity();
+  String getIdentity();
 
   /**
    * Return the SHA-1 digest of the authority's medium-term signing key
@@ -39,7 +41,7 @@ public interface DirectorySignature {
    *
    * @since 1.7.0
    */
-  public String getSigningKeyDigestSha1Hex();
+  String getSigningKeyDigestSha1Hex();
 
   /**
    * Return the directory signature string made with the authority's
@@ -47,6 +49,6 @@ public interface DirectorySignature {
    *
    * @since 1.0.0
    */
-  public String getSignature();
+  String getSignature();
 }
 
