@@ -23,6 +23,7 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Date;
 import java.util.List;
 import java.util.SortedMap;
 import java.util.TreeSet;
@@ -56,6 +57,16 @@ public class ServerDescriptorImplTest {
       return db.buildDescriptor();
     }
 
+    private String overloadLine = "overload-general 1 2021-08-06 13:00:00";
+
+    private static ServerDescriptor createWithOverloadLine(
+            String line) throws DescriptorParseException {
+      DescriptorBuilder db = new DescriptorBuilder();
+      db.overloadLine = line;
+      return db.buildDescriptor();
+    }
+
+
     private String platformLine = "platform Tor 0.2.2.35 "
         + "(git-b04388f9e7546a9f) on Linux i686";
 
@@ -361,6 +372,9 @@ public class ServerDescriptorImplTest {
       if (this.bandwidthLine != null) {
         sb.append(this.bandwidthLine).append("\n");
       }
+      if (this.overloadLine != null) {
+        sb.append(this.overloadLine).append("\n");
+      }
       if (this.platformLine != null) {
         sb.append(this.platformLine).append("\n");
       }
@@ -495,6 +509,10 @@ public class ServerDescriptorImplTest {
     assertEquals(51200, descriptor.getBandwidthRate());
     assertEquals(51200, descriptor.getBandwidthBurst());
     assertEquals(53470, descriptor.getBandwidthObserved());
+    assertEquals(1, descriptor.getOverloadGeneralVersion());
+    assertEquals(1628254800000L, descriptor.getOverloadGeneralTimestamp());
+    assertEquals("Fri Aug 06 13:00:00 UTC 2021",
+            new Date(descriptor.getOverloadGeneralTimestamp()).toString());
     assertEquals("1469D1550738A25B1E7B47CDDBCD7B2899F51B74",
         descriptor.getExtraInfoDigestSha1Hex());
     assertTrue(descriptor.isHiddenServiceDir());
@@ -510,9 +528,9 @@ public class ServerDescriptorImplTest {
     assertFalse(descriptor.getCachesExtraInfo());
     assertFalse(descriptor.getAllowSingleHopExits());
     assertTrue(descriptor.getUnrecognizedLines().isEmpty());
-    assertEquals("a9635dd801ad98dac43aff49baa2dbbaf050222d",
+    assertEquals("a31ed6a2dc8fba9cd40d123ff1018d53a7dd9b69",
         descriptor.getDigestSha1Hex());
-    assertEquals("kvdJKQ6R9i8x1nDqJZ34JFWsu6TquLqQy54nheSWrOY",
+    assertEquals("aZPim4xkyR/ZPUEZ9Fud2PPylX64rxz420bswb3MMiA",
         descriptor.getDigestSha256Base64());
   }
 
